# *NiBabies*: A robust preprocessing workflow tailored for neonate and infant MRI

[![github](https://github.com/nipreps/nibabies/actions/workflows/pytest.yml/badge.svg)](https://github.com/nipreps/nibabies/actions)
[![circle](https://circleci.com/gh/nipreps/nibabies/tree/master.svg?style=shield)](https://circleci.com/gh/nipreps/nibabies/tree/master)
[![dockerhub](https://img.shields.io/badge/docker-nipreps/nibabies-brightgreen.svg?logo=docker&style=flat)](https://hub.docker.com/r/nipreps/nibabies/tags/)
[![coverage](https://codecov.io/gh/nipreps/nibabies/branch/master/graph/badge.svg)](https://app.codecov.io/gh/nipreps/nibabies/branch/master)
[![documentation](https://readthedocs.org/projects/nibabies/badge/?version=latest)](https://nibabies.readthedocs.io/en/latest/)
[![DOI](https://zenodo.org/badge/264223087.svg)](https://zenodo.org/badge/latestdoi/264223087)

Anatomical | Functional
---------- | ----------
![nibabies-anat](https://raw.githubusercontent.com/nipreps/nibabies/master/docs/_static/nibabies_anat.png) | ![nibabies-func](https://raw.githubusercontent.com/nipreps/nibabies/master/docs/_static/nibabies_func.png)

*NiBabies* is an open-source software pipeline designed to process anatomical and functional magnetic resonance imaging data.
A member of the [NeuroImaging PREProcessing toolS (NiPreps)](https://www.nipreps.org/) family, *NiBabies* is designed and optimized for human infants between 0-2 years old.

---

## Getting Started

For comprehensive information on *NiBabies*, including installation and usage, visit [our documentation](https://nibabies.readthedocs.io/en/latest).
